==> service-catalog-examples-6.2.0-sources.jar: io/fabric8/servicecatalog/examples/ListServicePlans.java <==
package io.fabric8.servicecatalog.examples; /**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


import io.fabric8.servicecatalog.api.model.ClusterServicePlan;
import io.fabric8.servicecatalog.api.model.ClusterServicePlanList;
import io.fabric8.servicecatalog.client.ServiceCatalogClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ListServicePlans {
  private static final Logger logger = LoggerFactory.getLogger(ListServicePlans.class.getSimpleName());

  public static void main(String[] args) {
      ServiceCatalogClient client = ClientFactory.newClient(args);
      ClusterServicePlanList list = client.clusterServicePlans().list();
      ClusterServicePlan c;
      logger.info("Listing Cluster Service Plans:");
      list.getItems()
          .forEach(b -> logger.info(b.getSpec().getClusterServiceBrokerName() + "\t\t\t" + b.getSpec().getClusterServiceClassRef() + "\t\t\t" + b.getSpec().getExternalName()));
      logger.info("Done");
  }
}

==> service-catalog-examples-6.10.0-sources.jar: io/fabric8/servicecatalog/examples/ListServicePlans.java <==
/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.fabric8.servicecatalog.examples;

import io.fabric8.servicecatalog.api.model.ClusterServicePlan;
import io.fabric8.servicecatalog.api.model.ClusterServicePlanList;
import io.fabric8.servicecatalog.client.ServiceCatalogClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ListServicePlans {
  private static final Logger logger = LoggerFactory.getLogger(ListServicePlans.class.getSimpleName());

  public static void main(String[] args) {
    ServiceCatalogClient client = ClientFactory.newClient(args);
    ClusterServicePlanList list = client.clusterServicePlans().list();
    ClusterServicePlan c;
    logger.info("Listing Cluster Service Plans:");
    list.getItems()
        .forEach(b -> logger.info(b.getSpec().getClusterServiceBrokerName() + "\t\t\t" + b.getSpec().getClusterServiceClassRef()
            + "\t\t\t" + b.getSpec().getExternalName()));
    logger.info("Done");
  }
}
